@@ -6,12 +6,12 @@ fn main() -> Result<(), Box<dyn Error>> {
     let options = Options::default();
 
     let old = public_api_from_rustdoc_json_str(
-        &read_to_string("./tests/rustdoc_json/public_api-v0.2.0.json")?,
+        &read_to_string("./tests/rustdoc-json/example_api-v0.1.0.json")?,
         options,
     )?;
 
     let new = public_api_from_rustdoc_json_str(
-        &read_to_string("./tests/rustdoc_json/public_api-v0.4.0.json")?,
+        &read_to_string("./tests/rustdoc-json/example_api-v0.2.0.json")?,
         options,
     )?;
 
